@@ -87,8 +87,7 @@ class DXApp(DXObject, DXExecutable):
         if dxid is not None:
             if name is not None or alias is not None:
                 raise DXError("Did not expect name or alias to be given if dxid is given")
-            if re.match("app-[0-9a-zA-Z]{24}", dxid) is None or \
-                    len(dxid) != len('app') + 25:
+            if not re.match("^app-[0-9a-zA-Z]{24}$", dxid):
                 raise DXError("Given app ID does not match expected format")
             self._dxid = dxid
         elif name is not None:
@@ -178,8 +177,10 @@ class DXApp(DXObject, DXExecutable):
         resp = dxpy.api.app_new(dx_hash, **kwargs)
         self.set_id(dxid=resp["id"])
 
-    def describe(self, **kwargs):
+    def describe(self, fields=None, **kwargs):
         '''
+        :param fields: Hash where the keys are field names that should be returned, and values should be set to True (default is that all fields are returned)
+        :type fields: dict
         :returns: Description of the remote app object
         :rtype: dict
 
@@ -190,10 +191,14 @@ class DXApp(DXObject, DXExecutable):
         method.
 
         '''
+        describe_input = {}
+        if fields:
+            describe_input['fields'] = fields
         if self._dxid is not None:
-            self._desc = dxpy.api.app_describe(self._dxid, **kwargs)
+            self._desc = dxpy.api.app_describe(self._dxid, input_params=describe_input, **kwargs)
         else:
-            self._desc = dxpy.api.app_describe('app-' + self._name, alias=self._alias, **kwargs)
+            self._desc = dxpy.api.app_describe('app-' + self._name, alias=self._alias,
+                                               input_params=describe_input, **kwargs)
 
         return self._desc
 
