@@ -39,7 +39,8 @@ if dxpy.JOB_ID:
     DEFAULT_BUFFER_SIZE = 1024*1024*96
 
 class DXFile(DXDataObject):
-    '''
+    '''Remote file object handler.
+
     :param dxid: Object ID
     :type dxid: string
     :param project: Project ID
@@ -47,7 +48,16 @@ class DXFile(DXDataObject):
     :param mode: One of "r", "w", or "a" for read, write, and append modes, respectively
     :type mode: string
 
-    Remote file object handler.
+    .. note:: The attribute values below are current as of the last time
+              :meth:`~dxpy.bindings.DXDataObject.describe` was run.
+              (Access to any of the below attributes causes
+              :meth:`~dxpy.bindings.DXDataObject.describe` to be called
+              if it has never been called before.)
+
+    .. py:attribute:: media
+
+       String containing the Internet Media Type (also known as MIME type
+       or Content-type) of the file.
 
     .. automethod:: _new
 
@@ -429,6 +439,21 @@ class DXFile(DXDataObject):
             report_progress_fn(self, len(data))
 
     def get_download_url(self, duration=24*3600, preauthenticated=False, filename=None, project=None, **kwargs):
+        """
+        :param duration: number of seconds for which the generated URL will be valid
+        :type duration: int
+        :param preauthenticated: if True, generates a 'preauthenticated' download URL, which embeds authentication info in the URL and does not require additional headers
+        :type preauthenticated: bool
+        :param filename: desired filename of the downloaded file
+        :type filename: str
+        :param project: ID of a project containing the file (the download URL should be associated with this project)
+        :type project: str
+        :returns: download URL and dict containing HTTP headers to be supplied with the request
+        :rtype: tuple (str, dict)
+
+        Obtains a URL that can be used to directly download the
+        associated file.
+        """
         args = {"duration": duration, "preauthenticated": preauthenticated}
         if filename is not None:
             args["filename"] = filename
