@@ -646,8 +646,41 @@ class TestDXClient(DXTestCase):
             print str(shell1.buffer)
             print "*** End test_dxpy_session_isolation debug data"
 
-    @unittest.skipUnless(testutil.TEST_RUN_JOBS,
-                         'skipping test that would run jobs')
+class TestDXDescribe(DXTestCase):
+    def test_projects(self):
+        run("dx describe :")
+        run("dx describe " + self.project)
+        run("dx describe " + self.project + ":")
+
+        # need colon to recognize as project name
+        with self.assertSubprocessFailure(exit_code=3):
+            run(u"dx describe dxclient_test_pröject")
+
+        # bad project name
+        with self.assertSubprocessFailure(exit_code=3):
+            run("dx describe dne:")
+
+        # nonexistent project ID
+        with self.assertSubprocessFailure(exit_code=3):
+            run("dx describe project-123456789012345678901234")
+
+    def test_bad_current_project(self):
+        with self.assertSubprocessFailure(stderr_regexp='No matches found', exit_code=3):
+            run("dx describe nonexistent --project-context-id foo")
+
+        run("dx describe " + self.project + " --project-context-id foo")
+
+@unittest.skipUnless(testutil.TEST_RUN_JOBS,
+                     'skipping tests that would run jobs')
+class TestDXRun(DXTestCase):
+    def setUp(self):
+        self.other_proj_id = run("dx new project other --brief").strip()
+        super(TestDXRun, self).setUp()
+
+    def tearDown(self):
+        dxpy.api.project_destroy(self.other_proj_id, {'terminateJobs': True})
+        super(TestDXRun, self).tearDown()
+
     def test_dx_run_extra_args(self):
         # success
         applet_id = dxpy.api.applet_new({"project": self.project,
@@ -668,6 +701,133 @@ class TestDXClient(DXTestCase):
         with self.assertSubprocessFailure(stderr_regexp='JSON', exit_code=3):
             run("dx run " + applet_id + " --extra-args not-a-JSON-string")
 
+    def test_dx_run_clone(self):
+        applet_id = dxpy.api.applet_new({"project": self.project,
+                                         "dxapi": "1.0.0",
+                                         "runSpec": {"interpreter": "bash",
+                                                     "code": "echo 'hello'"}
+                                         })['id']
+        other_applet_id = dxpy.api.applet_new({"project": self.project,
+                                               "dxapi": "1.0.0",
+                                               "runSpec": {"interpreter": "bash",
+                                                           "code": "echo 'hello'"}
+                                           })['id']
+
+        def check_new_job_metadata(new_job_desc, cloned_job_desc, overridden_fields=[]):
+            '''
+            :param new_job_desc: the describe hash in the new job
+            :param cloned_job_desc: the description of the job that was cloned
+            :param overridden_fields: the metadata fields in describe that were overridden (and should not be checked)
+            '''
+            # check clonedFrom hash in new job's details
+            self.assertIn('clonedFrom', new_job_desc['details'])
+            self.assertEqual(new_job_desc['details']['clonedFrom']['executable'],
+                             cloned_job_desc.get('applet') or cloned_job_desc.get('app'))
+            for metadata in ['project', 'folder', 'name', 'runInput', 'systemRequirements']:
+                self.assertEqual(new_job_desc['details']['clonedFrom'][metadata],
+                                 cloned_job_desc[metadata])
+            # check not_overridden_fields match/have the correct transformation
+            all_fields = set(['name', 'project', 'folder', 'input', 'systemRequirements',
+                              'applet'])
+            fields_to_check = all_fields.difference(overridden_fields)
+            for metadata in fields_to_check:
+                if metadata == 'name':
+                    self.assertEqual(new_job_desc[metadata], cloned_job_desc[metadata] + ' (re-run)')
+                else:
+                    self.assertEqual(new_job_desc[metadata], cloned_job_desc[metadata])
+
+        # originally, set everything and have an instance type for all
+        # entry points
+        orig_job_id = run("dx run " + applet_id + ' -inumber=32 --name jobname --folder /output --instance-type dx_m1.large --brief -y').strip()
+        orig_job_desc = dxpy.api.job_describe(orig_job_id)
+        # control
+        self.assertEqual(orig_job_desc['name'], 'jobname')
+        self.assertEqual(orig_job_desc['project'], self.project)
+        self.assertEqual(orig_job_desc['folder'], '/output')
+        self.assertEqual(orig_job_desc['input'], {'number': 32})
+        self.assertEqual(orig_job_desc['systemRequirements'], {'*': {'instanceType': 'dx_m1.large'}})
+
+        # clone the job
+
+        # nothing different
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " --brief -y").strip())
+        check_new_job_metadata(new_job_desc, orig_job_desc)
+
+        # override applet
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " " + other_applet_id + " --brief -y").strip())
+        self.assertEqual(new_job_desc['applet'], other_applet_id)
+        check_new_job_metadata(new_job_desc, orig_job_desc, overridden_fields=['applet'])
+
+        # override name
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " --name newname --brief -y").strip())
+        self.assertEqual(new_job_desc['name'], 'newname')
+        check_new_job_metadata(new_job_desc, orig_job_desc, overridden_fields=['name'])
+
+        # override folder
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " --folder /otherfolder --brief -y").strip())
+        self.assertEqual(new_job_desc['folder'], '/otherfolder')
+        check_new_job_metadata(new_job_desc, orig_job_desc, overridden_fields=['folder'])
+
+        # override project
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " --project " + self.other_proj_id + " --brief -y").strip())
+        self.assertEqual(new_job_desc['project'], self.other_proj_id)
+        self.assertEqual(new_job_desc['folder'], '/')
+        check_new_job_metadata(new_job_desc, orig_job_desc, overridden_fields=['project', 'folder'])
+
+        # override input with -i
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " -inumber=42 --brief -y").strip())
+        self.assertEqual(new_job_desc['input'], {"number": 42})
+        check_new_job_metadata(new_job_desc, orig_job_desc, overridden_fields=['input'])
+
+        # add other input fields with -i
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " -inumber2=42 --brief -y").strip())
+        self.assertEqual(new_job_desc['input'], {"number": 32, "number2": 42})
+        check_new_job_metadata(new_job_desc, orig_job_desc, overridden_fields=['input'])
+
+        # override input with --input-json (original input discarded)
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " --input-json '{\"number2\": 42}' --brief -y").strip())
+        self.assertEqual(new_job_desc['input'], {"number2": 42})
+        check_new_job_metadata(new_job_desc, orig_job_desc, overridden_fields=['input'])
+
+        # override the blanket instance type
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " --instance-type dx_m1.medium --brief -y").strip())
+        self.assertEqual(new_job_desc['systemRequirements'],
+                         {'*': {'instanceType': 'dx_m1.medium'}})
+        check_new_job_metadata(new_job_desc, orig_job_desc,
+                               overridden_fields=['systemRequirements'])
+
+        # override instance type for specific entry point(s)
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " --instance-type '{\"some_ep\": \"dx_m1.medium\", \"some_other_ep\": \"dx_m1.xlarge\"}' --brief -y").strip())
+        self.assertEqual(new_job_desc['systemRequirements'],
+                         {'*': {'instanceType': 'dx_m1.large'},
+                          'some_ep': {'instanceType': 'dx_m1.medium'},
+                          'some_other_ep': {'instanceType': 'dx_m1.xlarge'}})
+        check_new_job_metadata(new_job_desc, orig_job_desc,
+                               overridden_fields=['systemRequirements'])
+
+        # new original job with entry point-specific systemRequirements
+        orig_job_id = run("dx run " + applet_id + " --instance-type '{\"some_ep\": \"dx_m1.medium\"}' --brief -y").strip()
+        orig_job_desc = dxpy.api.job_describe(orig_job_id)
+        self.assertEqual(orig_job_desc['systemRequirements'], {'some_ep': {'instanceType': 'dx_m1.medium'}})
+
+        # override all entry points
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " --instance-type dx_m1.large --brief -y").strip())
+        self.assertEqual(new_job_desc['systemRequirements'], {'*': {'instanceType': 'dx_m1.large'}})
+        check_new_job_metadata(new_job_desc, orig_job_desc, overridden_fields=['systemRequirements'])
+
+        # override a different entry point; original untouched
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " --instance-type '{\"some_other_ep\": \"dx_m1.large\"}' --brief -y").strip())
+        self.assertEqual(new_job_desc['systemRequirements'],
+                         {'some_ep': {'instanceType': 'dx_m1.medium'},
+                          'some_other_ep': {'instanceType': 'dx_m1.large'}})
+        check_new_job_metadata(new_job_desc, orig_job_desc, overridden_fields=['systemRequirements'])
+
+        # override the same entry point
+        new_job_desc = dxpy.api.job_describe(run("dx run --clone " + orig_job_id + " --instance-type '{\"some_ep\": \"dx_m1.large\"}' --brief -y").strip())
+        self.assertEqual(new_job_desc['systemRequirements'],
+                         {'some_ep': {'instanceType': 'dx_m1.large'}})
+        check_new_job_metadata(new_job_desc, orig_job_desc, overridden_fields=['systemRequirements'])
+
     @unittest.skipUnless(testutil.TEST_RUN_JOBS,
                          'skipping test that would run jobs')
     def test_dx_run_workflow(self):
@@ -824,6 +984,8 @@ class TestDXBuildApp(DXTestCase):
         self.assertEqual(app_describe["version"], "1.0.0")
         self.assertEqual(app_describe["name"], "minimal_app")
         self.assertFalse("published" in app_describe)
+        self.assertTrue(os.path.exists(os.path.join(app_dir, 'code.py')))
+        self.assertFalse(os.path.exists(os.path.join(app_dir, 'code.pyc')))
 
     @unittest.skipUnless(testutil.TEST_CREATE_APPS,
                          'skipping test that would create apps')
@@ -1271,6 +1433,26 @@ def main(in1):
         # Verify that the bundled depends appear in the same folder.
         self.assertEqual(resources_file_describe['folder'], '/subfolder')
 
+    def test_archive_in_another_project(self):
+        app_spec = {
+            "name": "archive_in_another_project",
+            "dxapi": "1.0.0",
+            "runSpec": {"file": "code.py", "interpreter": "python2.7"},
+            "inputSpec": [],
+            "outputSpec": [],
+            "version": "1.0.0"
+            }
+        app_dir = self.write_app_directory("archive_in_another_project", json.dumps(app_spec), "code.py")
+        temp_project_id = subprocess.check_output(
+            u"dx new project '{p}' --brief".format(p="Temporary working project"), shell=True).strip()
+        try:
+            subprocess.check_output("dx select {p}".format(p=temp_project_id), shell=True)
+            run("dx build -d {p}: {app_dir}".format(p=self.proj_id, app_dir=app_dir))
+            run("dx build --archive -d {p}: {app_dir}".format(p=self.proj_id, app_dir=app_dir))
+        finally:
+            subprocess.check_output("dx select {p}".format(p=self.proj_id), shell=True)
+            subprocess.check_output("dx rmproject --yes {p}".format(p=temp_project_id), shell=True)
+
 
 class TestDXBuildReportHtml(unittest.TestCase):
     js = "console.log('javascript');"
